# NR ResQml

This Python package converts a Delft 3D output file on NetCDF4 format to a ResQml database

The package supports accessing Delft 3D files on the file system or via an OpenDAP server

Output generated by this package is an .epc file (zip archive) representing the data objects of the ResQml database and an .h5 file containing all relevant data. When running the module, the path to a valid and empty output directory must be provided (any missing directories will be created).

Launching the package from the command line can be done as follows:

<pre>
python -m nrresqml /path/to/delft3d.nc /path/to/output/directory
</pre>

The input path may also be a url to a .nc file on an OpenDAP server.
